#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/23
#
# Ref: https://bitbucket.org/tokibito/django-bpmobile/src/7a09b1dea05c/bpmobile/utils.py
# Ref: http://code.google.com/p/emoji4unicode/source/browse/trunk/src/carrier_data.py
#
from itertools import izip
import re
import warnings

def code_to_unicode(code):
    u"""Convert character code(hex) to unicode"""
    def utf32chr(n):
        """utf32char for narrow build python"""
        return eval("u\'\\U%08X\'" % n)
    def lazy_unichr(n):
        try:
            return unichr(n)
        except ValueError:
            warnings.warn("Your python it built as narrow python. Make with "
                "'--enable-unicode=ucs4' configure option to build wide python")
            return utf32chr(n)
    if code and isinstance(code, basestring):
        clean_code = code.replace('>', '')
        if clean_code:
            return u''.join([lazy_unichr(int(code_char, 16)) for code_char in clean_code.split('+') if code_char])
    return None
def code_to_sjis(code):
    u"""Convert character code(hex) to string"""
    if code and isinstance(code, basestring):
        clean_code = code.replace('>', '')
        if clean_code:
            _code_to_sjis_char = lambda c: ''.join([chr(int("%c%c"%(a, b), 16)) for a, b in izip(c[0::2], c[1::2])])
            return ''.join([_code_to_sjis_char(code_char) for code_char in clean_code.split('+') if code_char])
    return None
def unicode_to_code(uni):
    if not uni:
        return u"0000"
    code = []
    for x in uni:
        code.append(u"%04x" % ord(x))
    return "+".join(code)

def get_range_from_code(code, ranges):
    for range in ranges:
        if range[0] <= code <= range[1]: return range
    return None

def create_regex_patterns(symbols):
    u"""create regex patterns for text, google, docomo, kddi and softbank via `symbols`
    
    create regex patterns for finding emoji character from text. the pattern character use
    `unicode` formatted character so you have to decode text which is not decoded.
    """
    pattern_unicode = []
    pattern_google = []
    pattern_docomo = []
    pattern_kddi = []
    pattern_softbank = []
    for x in symbols:
        if x.unicode.code: pattern_unicode.append(re.escape(unicode(x.unicode)))
        if x.google.code: pattern_google.append(re.escape(unicode(x.google)))
        if x.docomo.code: pattern_docomo.append(re.escape(unicode(x.docomo)))
        if x.kddi.code: pattern_kddi.append(re.escape(unicode(x.kddi)))
        if x.softbank.code: pattern_softbank.append(re.escape(unicode(x.softbank)))
#    pattern_unicode = re.compile(u"[%s]" % u''.join(pattern_unicode))
#    pattern_google = re.compile(u"[%s]" % u''.join(pattern_google))
#    pattern_docomo = re.compile(u"[%s]" % u''.join(pattern_docomo))
#    pattern_kddi = re.compile(u"[%s]" % u''.join(pattern_kddi))
#    pattern_softbank = re.compile(u"[%s]" % u''.join(pattern_softbank))
    pattern_unicode = re.compile(u"%s" % u'|'.join(pattern_unicode))
    pattern_google = re.compile(u"%s" % u'|'.join(pattern_google))
    pattern_docomo = re.compile(u"%s" % u'|'.join(pattern_docomo))
    pattern_kddi = re.compile(u"%s" % u'|'.join(pattern_kddi))
    pattern_softbank = re.compile(u"%s" % u'|'.join(pattern_softbank))
    return {
        #                forward            reverse
        'text':         (None,              pattern_unicode),
        'docomo_img':   (None,              pattern_unicode),
        'kddi_img':     (None,              pattern_unicode),
        'softbank_img': (None,              pattern_unicode),
        'google':       (pattern_google,    pattern_unicode),
        'docomo':       (pattern_docomo,    pattern_unicode),
        'kddi':         (pattern_kddi,      pattern_unicode),
        'softbank':     (pattern_softbank,  pattern_unicode),
    }
    
def create_translate_dictionaries(symbols):
    u"""create translate dictionaries for text, google, docomo, kddi and softbank via `symbols`
    
    create dictionaries for translate emoji character to carrier from unicode (forward) or to unicode from carrier (reverse).
    method return dictionary instance which key is carrier name and value format is `(forward_dictionary, reverse_dictionary)`
    each dictionary expect `unicode` format. any text not decoded have to be decode before using this dictionary (like matching key)
    
    DO NOT CONFUSE with carrier's UNICODE emoji. UNICODE emoji like `u"\uE63E"` for DoCoMo's sun emoji is not expected. expected character
    for DoCoMo's sun is decoded character from `"\xF8\x9F"` (actually decoded unicode of `"\xF8\xF9"` is `u"\uE63E"` however not all emoji
    can convert with general encode/decode method. conversion of UNICODE <-> ShiftJIS is operated in Symbol constructor and stored in Symbol's `sjis`
    attribute and unicode formatted is `usjis` attribute.)
        
    """
    unicode_to_text = {}
    unicode_to_docomo_img = {}
    unicode_to_kddi_img = {}
    unicode_to_softbank_img = {}
    unicode_to_google = {}
    unicode_to_docomo = {}
    unicode_to_kddi = {}
    unicode_to_softbank = {}
    google_to_unicode = {}
    docomo_to_unicode = {}
    kddi_to_unicode = {}
    softbank_to_unicode = {}
    for x in symbols:
        if x.unicode.keyable:
            unicode_to_text[unicode(x.unicode)] = x.unicode.fallback
            unicode_to_docomo_img[unicode(x.unicode)] = x.docomo.thumbnail
            unicode_to_kddi_img[unicode(x.unicode)] = x.kddi.thumbnail
            unicode_to_softbank_img[unicode(x.unicode)] = x.softbank.thumbnail
            unicode_to_google[unicode(x.unicode)] = unicode(x.google)
            unicode_to_docomo[unicode(x.unicode)] = unicode(x.docomo)
            unicode_to_kddi[unicode(x.unicode)] = unicode(x.kddi)
            unicode_to_softbank[unicode(x.unicode)] = unicode(x.softbank)
        if x.google.keyable: google_to_unicode[unicode(x.google)] = unicode(x.unicode)
        if x.docomo.keyable: docomo_to_unicode[unicode(x.docomo)] = unicode(x.unicode)
        if x.kddi.keyable: kddi_to_unicode[unicode(x.kddi)] = unicode(x.unicode)
        if x.softbank.keyable: softbank_to_unicode[unicode(x.softbank)] = unicode(x.unicode)
    return {
        #                forward                reverse
        'text':         (None,                  unicode_to_text),
        'docomo_img':   (None,                  unicode_to_docomo_img),
        'kddi_img':     (None,                  unicode_to_kddi_img),
        'softbank_img': (None,                  unicode_to_softbank_img),
        'google':       (google_to_unicode,     unicode_to_google),
        'docomo':       (docomo_to_unicode,     unicode_to_docomo),
        'kddi':         (kddi_to_unicode,       unicode_to_kddi),
        'softbank':     (softbank_to_unicode,   unicode_to_softbank),
    }



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/24
#
import unittest
import e4u

e4u.load()

DISPLAY_INFO = False

class TestCaseAbstract(object):
    _carrier = None
    _carrier_contents = None
    _unicode_contents = None
    _encoding = None
    
    def output(self, name, contents, expected, result):
        if not DISPLAY_INFO:
            return
        print "# %s #" % name
        print u"  Contents:\t%s" % contents
        print u"  Expected:\t%s" % expected
        print u"  Result:\t%s" % result
        print ""
        
    def test_carrier_to_unicode(self):
        contents = self._carrier_contents
        expected = self._unicode_contents
        profile = {
            'carrier': self._carrier,
            'encoding': self._encoding,
        }
        result = e4u.translate(contents, **profile)
        self.assertEqual(result, expected)
        self.output("%s => unicode" % self._carrier, contents, expected, result)
        
    def test_unicode_to_carrier(self):
        contents = self._unicode_contents
        expected = self._carrier_contents
        profile = {
            'reverse': True,
            'carrier': self._carrier,
            'encoding': self._encoding,
        }
        result = e4u.translate(contents, **profile)
        self.assertEqual(result, expected)
        self.output("unicode => %s" % self._carrier, contents, expected, result)
        
class DoCoMoTestCase(unittest.TestCase, TestCaseAbstract):
    _carrier = 'docomo'
    _carrier_contents = "\xF8\x9F \xF8\xA0 \xF8\xA1".decode('cp932', 'replace')
    _unicode_contents = u"\u2600 \u2601 \u2614"
    _encoding = 'cp932'
class KDDITestCase(unittest.TestCase, TestCaseAbstract):
    _carrier = 'kddi'
    _carrier_contents = "\xF6\x60 \xF6\x65 \xF6\x64".decode('cp932', 'replace')
    _unicode_contents = u"\u2600 \u2601 \u2614"
    _encoding = 'cp932'
    
    def test_birthday(self):
        symbol = e4u.get("511")
        self.assertEqual(symbol.docomo.unicode, u"\uE686")
        self.assertEqual(symbol.kddi.unicode, u"\uE5A0")
        self.assertEqual(symbol.softbank.unicode, u"\uE34B")
        
        for s in e4u._loader.symbols:
            if s.unicode.unicode == u"\uE5A0":
                print "found"
class SoftBankTestCase(unittest.TestCase, TestCaseAbstract):
    _carrier = 'softbank'
    _carrier_contents = u"\uE04A \uE049 \uE04B"
    _unicode_contents = u"\u2600 \u2601 \u2614"
    _encoding = None
    
    def test_conversion(self):
        pass
if __name__ == '__main__':
    e4u.load()
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/25
#
from utils import get_range_from_code

def get_stored_thumbnail_urls(carrier, base_url=r"/image/emoji/%s/%s.gif"):
    if not carrier.code:
        return None
    urls = []
    for code in carrier.code.split('+'):
        urls.append(base_url%(carrier._name, code.upper()))
    return urls

_code_to_docomo_id_ranges = (
    (0xE63E, 0xE6A5, 0x0001, 0x0068),
    (0xE6AC, 0xE6AE, 0x00A7, 0x00A9),
    (0xE6B1, 0xE6B3, 0x00AA, 0x00AC),
    (0xE6B7, 0xE6BA, 0x00AD, 0x00B0),
    (0xE6CE, 0xE6EB, 0x0069, 0x0086),
    (0xE6EC, 0xE70A, 0x0088, 0x00A6),
    (0xE70B, 0xE70B, 0x0087, 0x0087),
    (0xE70C, 0xE757, 0x0001, 0x004C),
)
def get_docomo_thumbnail_urls(docomo, base_url=r"http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/%s/images/%d.gif"):
    if not docomo.code:
        return None
    urls = []
    for code in docomo.code.split('+'):
        code = int(code, 16)
        if code >= 0xE70C:
            category = 'extention'
        else:
            category = 'basic'
        range = get_range_from_code(code, _code_to_docomo_id_ranges)
        offset = code - range[0]
        number = range[2] + offset
        urls.append(base_url % (category, number))
    return urls

def get_kddi_thumbnail_urls(kddi, base_url = r"http://mail.google.com/mail/e/ezweb_ne_jp/%s"):
    if not kddi.code:
        return None
    return [base_url % kddi._id]

_code_to_sjis_code_ranges = (
    (0xE001, 0xE05A, 0xF941, 0xF99B),
    (0xE101, 0xE15A, 0xF741, 0xF79B),
    (0xE201, 0xE25A, 0xF7A1, 0xF7FA),
    (0xE301, 0xE34D, 0xF9A1, 0xF9ED),
    (0xE401, 0xE44C, 0xFB41, 0xFB8D),
    (0xE501, 0xE53E, 0xFBA1, 0xFBDE),
)
# SoftBank may refuse access image from external so the code below may not work.
def get_softbank_thumbnail_urls(softbank, base_url = u"http://creation.mb.softbank.jp/web/img/%04X/%04X_20.gif"):
    if not softbank.code:
        return None
    urls = []
    for code in softbank.code.split('+'):
        code = int(code, 16)
        range = get_range_from_code(code, _code_to_sjis_code_ranges)
        urls.append(base_url % (range[0], code))
    return urls



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/23
#
import utils
import loader
import code
import symbol

_loader = None

def load(filename=None,
        url=r"https://raw.githubusercontent.com/googlei18n/emoji4unicode/master/data/emoji4unicode.xml",
        loader_class=None):
    u"""load google's `emoji4unicode` project's xml file. must call this method first to use `e4u` library. this method never work twice if you want to reload, use `e4u.reload()` insted."""
    if not has_loaded():
        reload(filename, url, loader_class)
        
def reload(filename=None,
        url=r"https://raw.githubusercontent.com/googlei18n/emoji4unicode/master/data/emoji4unicode.xml",
        loader_class=None):
    u"""reload google's `emoji4unicode` project's xml file. must call this method first to use `e4u` library."""
    if loader_class is None:
        loader_class = loader.Loader
    global _loader
    _loader = loader_class()
    _loader.load(filename, url)

def has_loaded():
    u"""get has `e4u.load()` method called or not."""
    return _loader != None

def get(id):
    u"""get symbol via id"""
    symbol_dictionary = _loader.symbol_dictionary
    return symbol_dictionary[id]

def translate_char(source_char, carrier, reverse=False, encoding=False):
    u"""translate unicode emoji character to unicode carrier emoji character (or reverse)
    
    Attributes:
        source_char   - emoji character. it must be unicode instance or have to set `encoding` attribute to decode
        carrier       - the target carrier
        reverse       - if you want to translate CARRIER => UNICODE, turn it True
        encoding      - encoding name for decode (Default is None)
    
    """
    if not isinstance(source_char, unicode) and encoding:
        source_char = source_char.decode(encoding, 'replace')
    elif not isinstance(source_char, unicode):
        raise AttributeError(u"`source_char` must be decoded to `unicode` or set `encoding` attribute to decode `source_char`")
    if len(source_char) > 1:
        raise AttributeError(u"`source_char` must be a letter. use `translate` method insted.")
    translate_dictionary = _loader.translate_dictionaries[carrier]
    if not reverse:
        translate_dictionary = translate_dictionary[0]
    else:
        translate_dictionary = translate_dictionary[1]
    if not translate_dictionary:
        return source_char
    return translate_dictionary.get(source_char, source_char)

def translate(source, carrier, reverse=False, encoding=None):
    u"""translate unicode text contain emoji character to unicode carrier text (or reverse)
    
    Attributes:
        source        - text contain emoji character. it must be unicode instance or have to set `encoding` attribute to decode
        carrier       - the target carrier
        reverse       - if you want to translate CARRIER TEXT => UNICODE, turn it True
        encoding      - encoding name for decode (Default is None)
    
    """
    if not isinstance(source, unicode) and encoding:
        source = source.decode(encoding, 'replace')
    elif not isinstance(source, unicode):
        raise AttributeError(u"`source` must be decoded to `unicode` or set `encoding` attribute to decode `source`")
    regex_pattern = _loader.regex_patterns[carrier]
    translate_dictionary = _loader.translate_dictionaries[carrier]
    if not reverse:
        regex_pattern = regex_pattern[0]
        translate_dictionary = translate_dictionary[0]
    else:
        regex_pattern = regex_pattern[1]
        translate_dictionary = translate_dictionary[1]
    if not regex_pattern or not translate_dictionary:
        return source
    return regex_pattern.sub(lambda m: translate_dictionary[m.group()], source)
#    return regex_pattern.sub(lambda m: translate_dictionary.get(m.group(), m.group()), source)

def _code_to_profile(code_class):
    carrier = code_class._name
    encoding = code_class._encoding
    return {'carrier': carrier, 'encoding': encoding}
TEXT_TRANSLATE_PROFILE          = {'carrier': 'text', 'encoding': 'utf8'}
DOCOMO_IMG_TRANSLATE_PROFILE    = {'carrier': 'docomo_img', 'encoding': 'utf8'}
KDDI_IMG_TRANSLATE_PROFILE      = {'carrier': 'kddi_img', 'encoding': 'utf8'}
SOFTBANK_IMG_TRANSLATE_PROFILE  = {'carrier': 'softbank_img', 'encoding': 'utf8'}
GOOGLE_TRANSLATE_PROFILE        = _code_to_profile(code.Google)
DOCOMO_TRANSLATE_PROFILE        = _code_to_profile(code.DoCoMo)
KDDI_TRANSLATE_PROFILE          = _code_to_profile(code.KDDI)
SOFTBANK_TRANSLATE_PROFILE      = _code_to_profile(code.SoftBank)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/24
#
from urllib import urlopen
from BeautifulSoup import BeautifulStoneSoup

from utils import create_regex_patterns, create_translate_dictionaries 
from symbol import Symbol

class Loader(object):
    # Properties
    symbols = property(lambda self: self._symbols)
    symbol_dictionary = property(lambda self: self._symbol_dictionary)
    regex_patterns = property(lambda self: self._regex_patterns)
    translate_dictionaries = property(lambda self: self._translate_dictionaries)
    
    
    def _load(self, xml):
        soup = BeautifulStoneSoup(xml)('e')
        symbols = []
        symbol_dictionary = {}
        for e in soup:
            s = Symbol(e)
            symbols.append(s)
            symbol_dictionary[s.id] = s
        self._symbols = symbols
        self._symbol_dictionary = symbol_dictionary
        self._regex_patterns = create_regex_patterns(self.symbols)
        self._translate_dictionaries = create_translate_dictionaries(self.symbols)
        
        
    def load(self, filename=None, url=r"https://raw.githubusercontent.com/googlei18n/emoji4unicode/master/data/emoji4unicode.xml"):
        if filename:
            xml = open(filename, 'r').read()
        else:
            xml = urlopen(url).read()
        self._load(xml)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/23
#
import code

__ALL__ = ['Symbol']

class Symbol(object):
    u"""Emoji symbol class"""
    def __init__(self, e):
        u"""Constructor of the Symbol. Do not call it manually. Use `Symbol.load()` insted
        
        Attribute:
            e        - the instance of BeautifulSoup represent emoji4unicode's e element.
        """ 
        # Get data from attribute
        self._id = e['id']
        self._text_fallback = e.get('text_fallback', u"")
        self._text_repr = e.get('text_repr', u"")
        # Get code from attribute
        self._unicode = code.Unicode(e, self.fallback)
        self._google = code.Google(e, self.fallback)
        self._docomo = code.DoCoMo(e, self.fallback)
        self._kddi = code.KDDI(e, self.fallback)
        self._softbank = code.SoftBank(e, self.fallback)
    # Properties
    fallback = property(lambda self: self._text_fallback or self._text_repr)
    id = property(lambda self: self._id)
    unicode = property(lambda self: self._unicode)
    google = property(lambda self: self._google)
    docomo = property(lambda self: self._docomo)
    kddi = property(lambda self: self._kddi)
    softbank = property(lambda self: self._softbank)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author:    alisue
# Date:        2011/03/24
#
# Ref: https://bitbucket.org/tokibito/django-bpmobile/src/7a09b1dea05c/bpmobile/utils.py
# Ref: http://code.google.com/p/emoji4unicode/source/browse/trunk/src/carrier_data.py
#
from utils import code_to_unicode, code_to_sjis, get_range_from_code
from thumbnails import get_docomo_thumbnail_urls, get_kddi_thumbnail_urls, get_softbank_thumbnail_urls

class Code(object):
    _name = None
    def __init__(self, e, fallback=None):
        self._id = e.get('id')
        code = e.get(self._name, None)
        if code:
            if code.startswith('>'):
                code = code[1:]
                self._duplicate = True
            else:
                self._duplicate = False
            self._code = code
            self._unicode = code_to_unicode(code)
        else:
            self._code = None
            self._unicode = None
        self._fallback = fallback
    def __unicode__(self):
        return self.unicode
    keyable = property(lambda self: self.code and not self.duplicate)
    duplicate = property(lambda self: self._duplicate)
    code = property(lambda self: self._code)
    unicode = property(lambda self: self._unicode or self.fallback)
    fallback = property(lambda self: self._fallback)

class Carrier(Code):
    _code_to_sjis_code_ranges = None
    def __init__(self, e, fallback):
        super(Carrier, self).__init__(e, fallback)
        if self.code:
            self._sjis_code = self._code_to_sjis_code(self.code)
            self._sjis = code_to_sjis(self._sjis_code)
        else:
            self._sjis_code = None
            self._sjis = None
    def _code_to_sjis_code(self, code):
        if not code:
            return None
        result = []
        for c in code.split("+"):
            c = int(c, 16)
            range = get_range_from_code(c, self._code_to_sjis_code_ranges)
            offset = c - range[0]
            dst = range[2] + offset
            result.append("%04X" % dst)
        return '+'.join(result)
    sjis_code = property(lambda self: self._sjis_code)
    sjis = property(lambda self: self._sjis or self.fallback.encode('cp932'))
    usjis = property(lambda self: self.sjis.decode('cp932', 'replace') or self.fallback)
    
    def _get_thumbnail_urls(self):
        raise NotImplementedError
    def _get_thumbnail_img(self):
        img = r"""<img src="%s" alt="%s" title="%s" style="width:1em;height:1em" />"""
        fallback = self.fallback
        urls = self._get_thumbnail_urls()
        if urls is None:
            return fallback
        results = []
        for url in urls:
            results.append(img % (url, fallback, fallback))
        return u''.join(results)
    thumbnail = property(_get_thumbnail_img)
    
class Unicode(Code):
    _name = 'unicode'
    _encoding = 'utf8'
class Google(Code):
    _name = 'google'
    _encoding = 'utf8'
class DoCoMo(Carrier):
    _name = 'docomo'
    _encoding = 'cp932'
    _code_to_sjis_code_ranges = (
        (0xE63E, 0xE69B, 0xF89F, 0xF8FC),
        (0xE69C, 0xE6DA, 0xF940, 0xF97E),
        (0xE6DB, 0xE757, 0xF980, 0xF9FC),
    )
    _code_to_docomo_id_ranges = (
        (0xE63E, 0xE6A5, 0x0001, 0x0068),
        (0xE6AC, 0xE6AE, 0x00A7, 0x00A9),
        (0xE6B1, 0xE6B3, 0x00AA, 0x00AC),
        (0xE6B7, 0xE6BA, 0x00AD, 0x00B0),
        (0xE6CE, 0xE6EB, 0x0069, 0x0086),
        (0xE6EC, 0xE70A, 0x0088, 0x00A6),
        (0xE70B, 0xE70B, 0x0087, 0x0087),
        (0xE70C, 0xE757, 0x0001, 0x004C),
    )

    def __unicode__(self):
        return self.usjis
    _get_thumbnail_urls = get_docomo_thumbnail_urls
    
class KDDI(Carrier):
    _name = 'kddi'
    _encoding = 'cp932'
    _code_to_sjis_code_ranges = (
        (0xE468, 0xE4A6, 0xF640, 0xF67E),
        (0xE4A7, 0xE523, 0xF680, 0xF6FC),
        (0xE524, 0xE562, 0xF740, 0xF77E),
        (0xE563, 0xE5B4, 0xF780, 0xF7D1),
        (0xE5B5, 0xE5CC, 0xF7E5, 0xF7FC),
        (0xE5CD, 0xE5DF, 0xF340, 0xF352),
        (0xEA80, 0xEAAB, 0xF353, 0xF37E),
        (0xEAAC, 0xEAFA, 0xF380, 0xF3CE),
        (0xEAFB, 0xEB0D, 0xF7D2, 0xF7E4),
        (0xEB0E, 0xEB3B, 0xF3CF, 0xF3FC),
        (0xEB3C, 0xEB7A, 0xF440, 0xF47E),
        (0xEB7B, 0xEB8E, 0xF480, 0xF493), 
    )
    def __unicode__(self):
        return self.usjis
    _get_thumbnail_urls = get_kddi_thumbnail_urls
    
class SoftBank(Carrier):
    _name = 'softbank'
    _encoding = 'utf8'
    _code_to_sjis_code_ranges = (
        (0xE001, 0xE03E, 0xF941, 0xF97E),
        (0xE03F, 0xE05A, 0xF980, 0xF99B),
        (0xE101, 0xE15A, 0xF741, 0xF79B),
        (0xE201, 0xE25A, 0xF7A1, 0xF7FA),
        (0xE301, 0xE34D, 0xF9A1, 0xF9ED),
        (0xE401, 0xE44C, 0xFB41, 0xFB8D),
        (0xE501, 0xE53E, 0xFBA1, 0xFBDE),
    )
    
    _get_thumbnail_urls = get_softbank_thumbnail_urls


#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# author:        alisue
# date:            2011/03/22
#
from setuptools import setup, find_packages

version = "0.1rc5"


def read(filename):
    import os.path
    return open(os.path.join(os.path.dirname(__file__), filename)).read()


setup(
    name="e4u",
    version=version,
    description=(
        "Python's emoji conversion (unicode emoji <=> carrier's emoji) "
        "library (emoji4unicode project wrapper library)"
    ),
    long_description=read('README.rst'),
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],
    keywords="emoji emoji4unicode mobile",
    author="Alisue",
    author_email="lambdalisue@hashnote.net",
    url=r"https://github.com/lambdalisue/e4u",
    download_url=r"https://github.com/lambdalisue/e4u/tarball/master",
    license='BSD',
    packages=find_packages(exclude=["test", "utils"]),
    include_package_data=True,
    zip_safe=True,
    install_requires=['setuptools', 'BeautifulSoup'],
)
